*********
Tutorials
*********

.. toctree::
   :maxdepth: 1

   intro-gpu
   uploading-datasets
   ../examples/microphone-demo/microphone-demo
   ../examples/coral-demo
   ../examples/micro-device-demo
